@@ -1,5 +1,5 @@
 def extract_questions(exam):
-    if "public" in exam:
+    if exam.get("public"):
         yield from group_questions(exam["public"])
     for group in exam["groups"]:
         yield from group_questions(group)
@@ -7,7 +7,10 @@ def extract_questions(exam):
 
 def group_questions(group):
     out = _group_questions(group)
-    first = next(out)
+    try:
+        first = next(out)
+    except StopIteration:
+        return
     first["text"] = group["name"] + "\n\n" + group["text"] + "\n\n" + first["text"]
     yield first
     yield from out
