@@ -6,7 +6,9 @@ def scramble(email, exam, *, keep_data=False):
 
     def scramble_group(group, substitutions, config, depth):
         group_substitutions = select(group["substitutions"])
-        group_substitutions.update(select_no_replace(group.get("substitutions_match", [])))
+        group_substitutions.update(
+            select_no_replace(group.get("substitutions_match", []))
+        )
         substitute(
             group,
             [*substitutions, group_substitutions],
@@ -27,10 +29,25 @@ def scramble(email, exam, *, keep_data=False):
                 scramble_question(
                     element, [*substitutions, group_substitutions], config
                 )
+        if (
+            group.get("pick_some") == 1
+            and not group["name"].strip()
+            and group["points"] is None
+            and depth != 1
+        ):
+            text, html, tex = group["text"], group["html"], group["tex"]
+            element = get_elements(group)[0]
+            group.clear()
+            group.update(element)
+            group["text"] = text + "\n" + group["text"]
+            group["html"] = html + "\n" + group["html"]
+            group["tex"] = tex + "\n" + group["tex"]
 
     def scramble_question(question, substitutions, config):
         question_substitutions = select(question["substitutions"])
-        question_substitutions.update(select_no_replace(question.get("substitutions_match", [])))
+        question_substitutions.update(
+            select_no_replace(question.get("substitutions_match", []))
+        )
         substitute(
             question, [question_substitutions, *substitutions], ["html", "tex", "text"]
         )
@@ -43,6 +60,21 @@ def scramble(email, exam, *, keep_data=False):
                     ["html", "tex", "text"],
                 )
 
+        if keep_data and "solution" in question:
+            solution = question["solution"]
+            if "solution" in solution:
+                substitute(
+                    solution, [question_substitutions, *substitutions], ["solution"]
+                )
+            else:
+                substitute(
+                    question["options"],
+                    [question_substitutions, *substitutions],
+                    range(len(question["options"])),
+                )
+        else:
+            question.pop("solution", None)
+
     def substitute(target: dict, list_substitutions, attrs):
         merged = {}
         for substitutions in list_substitutions:
@@ -93,6 +125,7 @@ def select(substitutions):
         out[k] = random.choice(v)
     return out
 
+
 def select_no_replace(substitutions_match):
     out = {}
     # DEFINE MATCH
