@@ -18,7 +18,7 @@ from examtool.cli.utils import exam_name_option, hidden_output_folder_option, pr
 @exam_name_option
 @click.option("--subtitle", prompt=True, default="Structure and Interpretation of Computer Programs")
 @hidden_output_folder_option
-@click.option("--do_twice", help="Run the compile twice for each student to fix weird rendering bugs.")
+@click.option("--do-twice", is_flag=True, help="Run the compile twice for each student to fix weird rendering bugs.")
 def compile_all(exam, subtitle, out, do_twice):
     """
     Compile individualized PDFs for the specified exam.
